# KubeVirt Collection for Ansible
<!-- Add CI and code coverage badges here. Samples included below. -->
[![CI](https://github.com/ansible-collections/community.kubevirt/workflows/CI/badge.svg?event=push)](https://github.com/ansible-collections/community.kubevirt/actions) [![Codecov](https://img.shields.io/codecov/c/github/ansible-collections/community.kubevirt)](https://codecov.io/gh/ansible-collections/community.kubevirt)

<!-- Describe the collection and why a user would want to use it. What does the collection do? -->

This repo hosts the `community.kubevirt` Ansible Collection.

The collection includes a variety of Ansible content to automate the management of KubeVirt container native virtualization environments.

##  Included Content

  - **Inventory Source**:
    - kubevirt
  - **Modules**:
    - kubevirt_cdi_upload
    - kubevirt_preset
    - kubevirt_pvc
    - kubevirt_rs
    - kubevirt_template
    - kubevirt_vm

<!-- ## Contributing to this collection -->

<!--Describe how the community can contribute to your collection. At a minimum, include how and where users can create issues to report problems or request features for this collection.  List contribution requirements, including preferred workflows and necessary testing, so you can benefit from community PRs. If you are following general Ansible contributor guidelines, you can link to - [Ansible Community Guide](https://docs.ansible.com/ansible/latest/community/index.html). -->

## Release notes

See the [changelog](https://github.com/ansible-collections/community.kubevirt/tree/main/CHANGELOG.rst).

## More Information

For more information about Ansible's Kubernetes integration, join the `#ansible-kubernetes` channel on Freenode IRC, and browse the resources in the [Kubernetes Working Group](https://github.com/ansible/community/wiki/Kubernetes) Community wiki page.

- [Ansible Collection overview](https://github.com/ansible-collections/overview)
- [Ansible User guide](https://docs.ansible.com/ansible/latest/user_guide/index.html)
- [Ansible Developer guide](https://docs.ansible.com/ansible/latest/dev_guide/index.html)
- [Ansible Collections Checklist](https://github.com/ansible-collections/overview/blob/master/collection_requirements.rst)
- [Ansible Community code of conduct](https://docs.ansible.com/ansible/latest/community/code_of_conduct.html)
- [The Bullhorn (the Ansible Contributor newsletter)](https://us19.campaign-archive.com/home/?u=56d874e027110e35dea0e03c1&id=d6635f5420)
- [Changes impacting Contributors](https://github.com/ansible-collections/overview/issues/45)

## Licensing

GNU General Public License v3.0 or later.

See [LICENSE](https://www.gnu.org/licenses/gpl-3.0.txt) to see the full text.
